about summary refs log tree commit diff
path: root/converter/other/tifftopnm.c
diff options
context:
space:
mode:
Diffstat (limited to 'converter/other/tifftopnm.c')
-rw-r--r--converter/other/tifftopnm.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/converter/other/tifftopnm.c b/converter/other/tifftopnm.c
index 05493e73..0c301a4a 100644
--- a/converter/other/tifftopnm.c
+++ b/converter/other/tifftopnm.c
@@ -1357,10 +1357,10 @@ convertRasterByRows(pnmOut *       const pnmOutP,
            represented as single array element, so it's easy to work with.
         */
     xel * xelrow;
         /* The ppm-format row of the image row we are presently converting */
     gray * alpharow;
         /* The pgm-format row representing the alpha values for the image
-           row we are presently converting.
+           row we are currently converting.
         */
 
     unsigned int row;
@@ -1465,11 +1465,11 @@ convertTiffRaster(uint32 *        const raster,
 -----------------------------------------------------------------------------*/
     xel * xelrow;
         /* The ppm-format row of the image row we are
-           presently converting
+           currently converting
         */
     gray * alpharow;
         /* The pgm-format row representing the alpha values
-           for the image row we are presently converting.
+           for the image row we are currently converting.
         */
     unsigned int row;
 
@@ -1478,7 +1478,7 @@ convertTiffRaster(uint32 *        const raster,
 
     for (row = 0; row < rows; ++row) {
         uint32 * rp;
             /* Address of pixel in 'raster' we are presently converting */
         unsigned int col;
 
         /* Start at beginning of row: */
@@ -1357,10 +1357,10 @@ convertRasterByRows(pnmOut *       const pnmOutP,
         */
     xel * xelrow;
-        /* The ppm-format row of the image row we are presently converting */
+        /* The ppm-format row of the image row we are currently converting */
     gray * alpharow;
         /* The pgm-format row representing the alpha values for the image
@@ -1478,7 +1478,7 @@ convertTiffRaster(uint32 *        const raster,
     for (row = 0; row < rows; ++row) {
         uint32 * rp;
-            /* Address of pixel in 'raster' we are presently converting */
+            /* Address of pixel in 'raster' we are currently converting */
         unsigned int col;
 